<template>
  <div class="common-page-shadow">
    <div class="common-search-container" ref="contentPanel">
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        type="flex"
        justify="left"
      >
        <el-row :gutter="25">
          <el-col :span="6">
            <el-form-item label="收费站">
              <el-select
                clearable
                size="small"
                v-model="searchForm.tollStationId"
                filterable
                placeholder="收费站"
              >
                <el-option
                  v-for="item in tollStationData"
                  :key="item.id"
                  :label="item.name"
                  :value="item.id"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="年份">
              <el-date-picker
                size="small"
                v-model="searchForm.costYear"
                type="year"
                align="right"
                format="yyyy"
                value-format="yyyy"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-search"
              type="primary"
              class="btn btn-plus"
              @click="handleSearch"
            >
              {{ this.$t('common.search') }}
            </el-button>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-refresh-right"
              class="btn btn-plus"
              @click="clearSearchForm"
            >
              重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row
      class="common-table-container flex searchPanel"
      :style="SearchPanel"
    >
      <el-col :span="24" class="common-table-wrapper">
        <div class="common-btn-group">
          <el-button
            size="small"
            icon="el-icon-plus"
            type="primary"
            class="btn btn-plus"
            @click="handleAdd"
            v-methodauth="'saveCharge'"
          >
            {{ this.$t('common.add') }}
          </el-button>
          <el-button
            size="small"
            slot="reference"
            icon="el-icon-delete"
            type="danger"
            class="btn btn-delete"
            :disabled="deleteIds.length ? false : true"
            @click="handleDelete"
            v-methodauth="'removeCharge'"
          >
            {{ this.$t('common.delete') }}
          </el-button>
        </div>
        <!-- LJ：表格高度自适应需配合样式  btn-pagenation 有按钮有分页  btngroup只有按钮  pagenation只有分页 -->
        <div class="common-table-content btn-pagenation">
          <el-table
            :border="true"
            stripe
            fit
            size="mini"
            v-loading="tableLoading"
            ref="multipleSelection"
            :data="tableData"
            height="100%"
            @selection-change="handleSelectionChange"
            @row-dblclick="handleEdit"
          >
            <el-table-column type="selection" width="55" align="center">
            </el-table-column>
            <el-table-column
              prop="tollStationName"
              show-overflow-tooltip
              label="收费站"
              align="left"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="costYear"
              show-overflow-tooltip
              label="年份"
              align="left"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="incomePlan"
              show-overflow-tooltip
              align="left"
              label="收入指标"
              resizable
            >
            </el-table-column>
            <el-table-column width="100" align="left" label="操作">
              <template v-slot="{row}">
                <el-button type="text" size="small" @click="handleEdit(row)"
                  >编辑</el-button
                >
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div class="common-pagenation">
          <el-pagination
            ref="paginationPanel"
            background
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="params.pageBean.page"
            :page-sizes="[20, 30, 40, 50]"
            :page-size="params.pageBean.pageSize"
            layout="total, sizes, prev, pager, next, jumper"
            :total="params.pageBean.total"
          >
          </el-pagination>
        </div>
      </el-col>
    </el-row>
    <!-- 弹层 -->
    <el-dialog
      :title="dialog.title"
      :visible.sync="dialog.visible"
      width="600px"
      top="10vh"
      :before-close="handleDialogClose"
      :close-on-click-modal="false"
      :destroy-on-close="true"
    >
      <el-form
        ref="form"
        :model="dialogForm"
        :rules="rules"
        label-width="100px"
        label-position="right"
        v-loading="loading"
        :disabled="disabledDetils"
        border
      >
        <el-row :gutter="20" type="flex" class="flex-wrap">
          <el-col :span="22">
            <el-form-item label="收费站" prop="tollStationId">
              <el-select
                v-model="dialogForm.tollStationId"
                filterable
                placeholder="收费站"
              >
                <el-option
                  v-for="item in tollStationData"
                  :key="item.id"
                  :label="item.name"
                  :value="item.id"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="22">
            <el-form-item label="年份" prop="costYear">
              <el-date-picker
                v-model="dialogForm.costYear"
                type="year"
                align="right"
                value-format="yyyy"
                format="yyyy"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="22">
            <el-form-item label="收入指标" prop="incomePlan">
              <el-input
                v-model="dialogForm.incomePlan"
                :disabled="disabled"
                placeholder="收入指标"
                type="number"
                class="NumberType"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="dialog.visible = false" size="small">
          取消
        </el-button>
        <template v-if="!disabledDetils">
          <el-button type="primary" @click="submit()" size="small">
            提交
          </el-button>
        </template>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import tollStationManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import chargeData from '@/api/DataManagement/chargeData.js'
import incomePlan from '@/api/DataManagement/incomePlan.js'
export default {
  name: 'inconePlan',
  mixins: [TableMixin],
  data() {
    return {
      searchForm: {},
      params: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0,
        },
      },
      loading: false,
      disabledDetils: false,
      tableLoading: false,
      tableData: [],
      dialog: {
        title: '添加',
        visible: false,
      },
      dialogForm: {
        tollStationId: '',
        tollStationName: '',
        costYear: '',
      },
      disabled: false, // 是否禁止输入输入
      edit: false, // 是否是修改功能
      rules: {},
      roadOptions: [],
    }
  },
  created() {
    this.tollStationId = sessionStorage.getItem('tollStationId')
    this.loadTollStation()
  },
  methods: {
    // 获取收费站数据
    loadTollStation() {
      this.tollStationData = []
      let queryData = {
        pageBean: {
          page: 1,
          pageSize: -1,
          total: 0,
        },
      }
      tollStationManagement.queryTollStation(queryData).then((res) => {
        if (res.data && res.data.rows) {
          this.tollStationData = res.data.rows || []
        }
        let target = res.data.rows.filter(
          (item) => item.id == this.tollStationId
        )
        if (target && target.length) {
          this.dialogForm.tollStationName = target[0].name
          this.dialogForm.tollStationId = target[0].id
          this.searchForm.tollStationId = target[0].id
        }
        this.loadData(1)
      })
    },
    //获取数据
    loadData(page) {
      if (page) this.params.pageBean.page = page
      this.tableLoading = true
      incomePlan.queryData(this.params).then((res) => {
        this.tableLoading = false
        this.tableData = res.value.rows || []
        if (res.value.page) {
          this.params.pageBean = {
            page: res.value.page,
            pageSize: res.value.pageSize,
            total: res.value.total,
          }
        }
      })
    },
    handleSearch() {
      let querys = []
      for (let key in this.searchForm) {
        querys.push({
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: key,
          relation: 'AND',
          value: this.searchForm[key],
        })
      }
      this.params.querys = querys
      this.loadData(1)
    },
    handleDelete() {
      this.$confirm(this.$t('common.sureDelete'), this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning',
      }).then(() => {
        incomePlan.DeleteConfig(this.deleteIds).then((res) => {
          this.loadData(1)
          if (res.data.state) {
            this.$message({
              message: '删除成功',
              type: 'success',
            })
          }
        })
      })
    },
    // 表单提交保存
    submit() {
      this.$refs.form.validate((valid) => {
        for (let i = 0; i < this.tollStationData.length; i++) {
          if (
            this.dialogForm.tollStationId ==
            this.tollStationData[i].tollStationId
          ) {
            this.dialogForm.tollStationName =
              this.tollStationData[i].tollStationName
          }
        }
        if (valid) {
          this.loading = true
          incomePlan
            .saveData(this.dialogForm)
            .then((res) => {
              if (res.data.state) {
                this.dialog.visible = false
                this.loadData(1)
              }
              if (!res.errorMsg) {
                this.$message({
                  message: !this.edit ? '添加成功' : '修改成功',
                  type: 'success',
                })
                this.editVisible = false
              }
              this.loading = false
            })
            .catch(() => {
              this.loading = false
            })
        } else {
          return false
        }
      })
    },
    // 弹层关闭
    handleDialogClose() {
      this.$refs.form.resetFields()
      this.dialogForm = {}
      this.dialogForm.tollStationId = this.tollStationId
      this.dialog.visible = false
    },
    //添加
    handleAdd() {
      this.edit = false
      this.disabledDetils = false
      this.dialog.title = '添加'
      this.dialog.visible = true
    },
    // 编辑
    handleEdit(rows) {
      this.$refs.form.clearValidate()
      this.edit = true
      this.disabledDetils = false
      this.dialogForm = {
        ...rows,
      }
      // this.dialogForm.costYear = toString(this.dialogForm.costYear)
      this.dialog.title = '编辑'
      this.dialog.visible = true
    },
    clearSearchForm() {
      this.searchForm = {}
      this.searchForm.tollStationId = this.tollStationId
      this.handleSearch()
    },
    formatPassTime(data) {
      let totalseconds = data // 时长 以秒为单位
      let hh = 0 //小时 默认0
      let mm = Math.floor(totalseconds / 60) //除以60取整数，得到整数分钟

      // 如果分钟大于60，将分钟转换成小时
      if (mm > 60) {
        // 获取小时整数
        hh = Math.floor(mm / 60)

        // 取余的分钟数
        mm = mm % 60
      }
      let ss = totalseconds % 60 // 取余得秒

      function addZero(n) {
        let temp
        n < 10 ? (temp = '0' + n) : (temp = n)
        return temp
      }
      return addZero(hh) + ':' + addZero(mm) + ':' + addZero(ss)
    },
  },
  computed: {
    SearchPanel() {
      return {
        '--searchPanel': this.searchPanel + 'px',
      }
    },
  },
}
</script>

<style lang="scss" scoped>
  /deep/.el-input input::-webkit-outer-spin-button,
    /deep/.el-input input::-webkit-inner-spin-button {
        -webkit-appearance: none!important;
    }
    /deep/.el-input input[type="number"]{
        -moz-appearance: textfield;
    }
    /deep/.el-input .el-input__inner {
        line-height: 1px!important;
    }

</style>